<?php

namespace App\Console\Commands\Bundle;

use App\Classes\Bundle;
use App\Console\Commands\Bundle\Traits\ReadsBundles;
use App\Console\Commands\Bundle\Traits\SelectsDisks;
use Illuminate\Console\Command;

use function Laravel\Prompts\progress;

class Upgrade extends Command
{
    use ReadsBundles;
    use SelectsDisks;

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Upgrade bundles from previous CMS version';

    public function __construct()
    {
        $this->signature = 'bundle:upgrade 
            { --r|recursive     : Also upgrade sub-bundles } 
            { --source-disk=    : Use specified content disk - Defaults to <info>' . env('CONTENT_DISK') . '</info> }
            { path?             : Path to a specific bundle to upgrade - Default to <info>/</info> }
        ';

        parent::__construct();
    }

    /**
     * Execute the console command.
     */
    public function handle()
    {
        $this->selectDisk()
            ->selectBundles()
            ->upgrade();
    }

    private function upgrade()
    {
        progress('Upgrading bundles...', $this->bundles, function (Bundle $bundle, $progress) {
            $this->handleBundle($bundle, $progress);
        });
    }

    private function handleBundle(Bundle $bundle, $progress)
    {
        //
    }
}
