<?php

namespace App\Providers;

use App\Services\Wikidata\WikidataClient;
use App\Services\Wikidata\WikidataExtractor;
use Illuminate\Support\ServiceProvider;

class WikidataServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     */
    public function register(): void
    {
        $this->app->singleton(WikidataClient::class, function ($app) {
            $config = $app['config']->get('services.wikidata');

            return new WikidataClient($config);
        });

        $this->app->singleton(WikidataExtractor::class, function ($app) {
            $inclusions = $app['config']->get('wikidata.inclusions', []);
            $exclusions = $app['config']->get('wikidata.exclusions', []);
            $templates  = $app['config']->get('wikidata.templates', []);

            return new WikidataExtractor($exclusions, $inclusions, $templates);
        });
    }

    /**
     * Bootstrap services.
     */
    public function boot(): void
    {
        //
    }
}
