<?php

namespace App\Services\AI\Contracts;

interface ProvidesAIServices
{
    /**
     * Options are needed for instanciating a provider
     */
    public function __construct(array $options);

    /**
     * Set provider's base URL, which is the root of its API
     */
    public function baseUrl(string $url): self;

    /**
     * Set API endpoint used for next request
     */
    public function endpoint(string $endpoint): self;

    /**
     * Add some headers to the request
     */
    public function withHeaders(array $header): self;

    /**
     * Provides low-level options to the provider. They will be integrated into
     * request's body.
     */
    public function withOptions(array $options): self;

    /**
     * Define the service used for next request
     */
    public function forService(string $service): self;

    /**
     * Sets the prompt used in next request
     */
    public function withPrompt(string $prompt): self;

    /**
     * Sets the model(s) to use during this request life-cycle
     */
    public function withModels(array $models): self;

    /**
     * Embed files in the message
     */
    public function withFiles(array $files): self;
}
