<?php

namespace App\Services\BundleRenderers\Renderers;

use App\Classes\Bundle;

class DossierRenderer extends BaseRenderer
{
    /**
     * Renders a complete HTML view of the bundle
     */
    public function render(bool $ignoreCache = false)
    {
        $this->prepareRender();

        $parts       = preg_split('#/#', $this->bundle->getPath(), -1, PREG_SPLIT_NO_EMPTY);
        $dossierPath = implode('/', [$parts[0], $parts[1]]);
        $dossier     = new Bundle($dossierPath, $this->bundle->getDisk());

        data_set($this->viewData, 'showToc', true);
        data_set($this->viewData, 'dossier', $dossier);

        return [$this->bundle->getPath() => $this->renderPage()];
    }

    /**
     * Renders a card HTML view of the bundle, suitable to display in lists
     */
    public function renderCard()
    {
        $this->prepareRenderCard();

        return $this->renderView('dossier-card');
    }

    /**
     * Return a boolean value indicating if this creator in particular can
     * create bundles for specified section
     */
    public static function handles(Bundle $bundle): bool
    {
        return $bundle->getSection() && $bundle->getSection()->getPath() === '/dossiers/';
    }

    protected function handlePagination(int $currentPage = 1)
    {
    }

    protected function collectSubBundles()
    {
        return [];
    }
}
