<?php

namespace App\Services\Partners\Partners;

use App\Services\Partners\Contracts\Partner;
use Exception;
use Illuminate\Support\Str;
use League\Uri\Uri;

abstract class BasePartner implements Partner
{
    protected static array $handledHosts;

    public function __construct(protected string $url)
    {
    }

    /**
     * Return an affiliate link corresponding to original URL
     */
    abstract public function getAffiliateLink(): string;

    /**
     * Return a boolean value indicating if the partner can handle specified
     * host extracted from a link
     */
    public static function handles(string $host): bool
    {
        if (isset(static::$handledHosts)) {
            return in_array($host, static::$handledHosts)
                || in_array('www.' . $host, static::$handledHosts)
                || in_array(Str::remove('www.', $host), static::$handledHosts);
        }
    }

    /**
     * Return an instance of a partner using specified url.
     */
    public static function make(string $url): Partner
    {
        return new static($url);
    }

    /**
     * Return a simple, tag-based in-url tracking id affiliated link
     */
    protected function getSimpleAffiliationLink(string $serviceName, string $urlParam, string $trackingId): string
    {
        if (empty($trackingId)) {
            throw new Exception(sprintf('Empty %s tracking id', $serviceName));
        }

        if (strpos($this->url, $trackingId) !== false) {
            return $this->url;
        }

        $uri = Uri::new($this->url)->withQuery(sprintf('%s=%s', $urlParam, $trackingId));

        return (string) $uri;
    }
}
